Pack<T> class Pack

The pack layout produces circle-packing diagrams, where the area of each leaf circle is proportional its value.

Circle-Packing

The enclosing circles show the approximate cumulative size of each subtree, but due to wasted space there is some distortion; only the leaf nodes can be compared accurately. Although circle packing does not use space as efficiently as a treemap, the “wasted” space more prominently reveals the hierarchical structure.

Constructors

Pack()
Creates a new pack layout with the default settings.

Properties

hashCode int
The hash code for this object.
no setterinherited
padding num Function(HierarchyNode<T>)
The padding is used to separate tangent siblings. Defaults to zero.
getter/setter pair
radius num Function(HierarchyNode<T>)?
Specifies the radius of each leaf circle.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size List<num>
The pack layout size specified as a two-element list of numbers [width, height]. The default is [1, 1].
getter/setter pair

Methods

call(HierarchyNode<T> root) HierarchyNode<T>
Lays out the specified root hierarchy.
constPadding(num padding) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited